@@ -14,3 +14,17 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
+
+use crate::error::ApiError;
+use serde::Deserialize;
+
+#[derive(Debug, Clone, Deserialize)]
+pub(crate) struct LoginResponse {
+    pub(crate) login: LoginInnerResponse,
+}
+
+#[derive(Debug, Clone, Deserialize)]
+pub(crate) struct LoginInnerResponse {
+    pub(crate) reason: ApiError,
+    pub(crate) result: String,
+}
